@@ -439,6 +439,19 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
                 lookup_path=lookup_path, mbrid=mbrid
             )
 
+        log.info('--> Creating loopback config')
+        loopback_file = os.path.normpath(
+            os.sep.join(
+                [
+                    self.boot_dir, self.get_boot_path(),
+                    self.boot_directory_name, '/loopback.cfg'
+                ]
+            )
+        )
+        self._create_loopback_config(
+            loopback_file
+        )
+
     def setup_live_boot_images(self, mbrid, lookup_path=None):
         """
         Create/Provide grub2 boot images and metadata
@@ -643,7 +656,7 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
         grub_final_cmdline = re.sub(
             r'(^root=[^\s]+)|( root=[^\s]+)', '', self.cmdline
         ).strip()
-        if self.persistency_type != 'by-uuid':
+        if self.persistency_type == 'by-label':
             grub_default_entries['GRUB_DISABLE_LINUX_UUID'] = 'true'
         if self.displayname:
             grub_default_entries['GRUB_DISTRIBUTOR'] = '"{0}"'.format(
@@ -1403,3 +1416,11 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
             raise KiwiDiskGeometryError(
                 'unknown format for disk geometry: %s' % fdasd_output
             )
+
+    def _create_loopback_config(self, filename):
+        with open(filename, 'w') as loopback_cfg:
+            loopback_cfg.write(
+                'source /boot/{0}/grub.cfg{1}'.format(
+                    self.boot_directory_name, os.linesep
+                )
+            )
