@@ -16,6 +16,7 @@
 # along with kiwi.  If not, see <http://www.gnu.org/licenses/>
 #
 import logging
+from typing import Dict
 
 # project
 from kiwi.defaults import Defaults
@@ -23,6 +24,7 @@ from kiwi.archive.tar import ArchiveTar
 from kiwi.system.setup import SystemSetup
 from kiwi.system.result import Result
 from kiwi.runtime_config import RuntimeConfig
+from kiwi.xml_state import XMLState
 
 from kiwi.exceptions import (
     KiwiArchiveSetupError
@@ -35,13 +37,16 @@ class ArchiveBuilder:
     """
     **Root archive image builder**
 
-    :param obsject xml_state: Instance of :class:`XMLState`
+    :param object xml_state: Instance of :class:`XMLState`
     :param str target_dir: target directory path name
     :param str root_dir: root directory path name
     :param dict custom_args: Custom processing arguments defined as hash keys:
         * xz_options: string of XZ compression parameters
     """
-    def __init__(self, xml_state, target_dir, root_dir, custom_args=None):
+    def __init__(
+        self, xml_state: XMLState, target_dir: str,
+        root_dir: str, custom_args: Dict = None
+    ):
         self.root_dir = root_dir
         self.target_dir = target_dir
         self.xml_state = xml_state
@@ -56,7 +61,7 @@ class ArchiveBuilder:
 
         self.runtime_config = RuntimeConfig()
 
-    def create(self):
+    def create(self) -> Result:
         """
         Create a root archive tarball
 
@@ -83,7 +88,9 @@ class ArchiveBuilder:
             )
             archive.create_xz_compressed(
                 self.root_dir, xz_options=self.xz_options,
-                exclude=Defaults.get_exclude_list_for_root_data_sync()
+                exclude=Defaults.
+                get_exclude_list_for_root_data_sync() + Defaults.
+                get_exclude_list_from_custom_exclude_files(self.root_dir)
             )
             Result.verify_image_size(
                 self.runtime_config.get_max_size_constraint(),
@@ -125,7 +132,7 @@ class ArchiveBuilder:
             )
         return self.result
 
-    def _target_file_for(self, suffix):
+    def _target_file_for(self, suffix: str) -> str:
         return ''.join(
             [
                 self.target_dir, '/',
