@@ -18,11 +18,16 @@
 import re
 import os
 import logging
+from typing import List
 
 # project
+from kiwi.command import command_call_type
 from kiwi.command import Command
 from kiwi.path import Path
 from kiwi.package_manager.base import PackageManagerBase
+from kiwi.system.root_bind import RootBind
+from kiwi.repository.apt import RepositoryApt
+
 from kiwi.exceptions import (
     KiwiDebootstrapError,
     KiwiRequestError
@@ -33,15 +38,15 @@ log = logging.getLogger('kiwi')
 
 class PackageManagerApt(PackageManagerBase):
     """
-    **Implements base class for installation/deletion of
-    packages and collections using apt-get**
+    **Implements Installation/Deletion of packages/collections with apt-get**
 
-    :param list apt_get_args: apt-get arguments from repository runtime
-        configuration
-    :param dict command_env: apt-get command environment from repository
+    :param list apt_get_args:
+        apt-get arguments from repository runtime configuration
+    :param dict command_env:
+        apt-get command environment from repository
         runtime configuration
     """
-    def post_init(self, custom_args=None):
+    def post_init(self, custom_args: List = []) -> None:
         """
         Post initialization method
 
@@ -49,10 +54,10 @@ class PackageManagerApt(PackageManagerBase):
 
         :param list custom_args: custom apt-get arguments
         """
+        self.repository: RepositoryApt = self.repository
         self.custom_args = custom_args
-        if not custom_args:
-            self.custom_args = []
-        self.deboostrap_minbase = True
+
+        self.deboostrap_minbase: bool = True
 
         runtime_config = self.repository.runtime_config()
         self.apt_get_args = runtime_config['apt_get_args']
@@ -60,7 +65,7 @@ class PackageManagerApt(PackageManagerBase):
         self.distribution = runtime_config['distribution']
         self.distribution_path = runtime_config['distribution_path']
 
-    def request_package(self, name):
+    def request_package(self, name: str) -> None:
         """
         Queue a package request
 
@@ -68,7 +73,7 @@ class PackageManagerApt(PackageManagerBase):
         """
         self.package_requests.append(name)
 
-    def request_collection(self, name):
+    def request_collection(self, name: str) -> None:
         """
         Queue a collection request
 
@@ -80,7 +85,7 @@ class PackageManagerApt(PackageManagerBase):
             'Collection(%s) handling not supported for apt-get', name
         )
 
-    def request_product(self, name):
+    def request_product(self, name: str) -> None:
         """
         Queue a product request
 
@@ -92,7 +97,7 @@ class PackageManagerApt(PackageManagerBase):
             'Product(%s) handling not supported for apt-get', name
         )
 
-    def request_package_exclusion(self, name):
+    def request_package_exclusion(self, name: str) -> None:
         """
         Queue a package exclusion(skip) request
 
@@ -104,7 +109,9 @@ class PackageManagerApt(PackageManagerBase):
             'Package exclusion for (%s) not supported for apt-get', name
         )
 
-    def process_install_requests_bootstrap(self, root_bind=None):
+    def process_install_requests_bootstrap(
+        self, root_bind: RootBind = None
+    ) -> command_call_type:
         """
         Process package install requests for bootstrap phase (no chroot)
         The debootstrap program is used to bootstrap a new system with
@@ -138,13 +145,20 @@ class PackageManagerApt(PackageManagerBase):
         # debootstrap. Debootstrap manages itself the kernel file systems for
         # chroot environment, thus we need to umount the kernel file systems
         # before calling debootstrap and remount them afterwards.
-        root_bind.umount_kernel_file_systems()
-        # debootsrap will create its own dev/fd device
-        os.unlink(os.path.normpath(os.sep.join([self.root_dir, 'dev/fd'])))
+        if root_bind:
+            root_bind.umount_kernel_file_systems()
 
-        if 'apt-get' in self.package_requests:
-            # debootstrap takes care to install apt-get
-            self.package_requests.remove('apt-get')
+        # debootsrap will create its own dev/fd devices
+        debootstrap_device_node_conflicts = [
+            'dev/fd',
+            'dev/pts'
+        ]
+        for node in debootstrap_device_node_conflicts:
+            Path.wipe(os.path.normpath(os.sep.join([self.root_dir, node])))
+
+        if 'apt' in self.package_requests:
+            # debootstrap takes care to install apt
+            self.package_requests.remove('apt')
         try:
             cmd = ['debootstrap']
             if self.repository.unauthenticated == 'false' and \
@@ -175,7 +189,9 @@ class PackageManagerApt(PackageManagerBase):
                 '%s: %s' % (type(e).__name__, format(e))
             )
 
-    def post_process_install_requests_bootstrap(self, root_bind=None):
+    def post_process_install_requests_bootstrap(
+        self, root_bind: RootBind = None
+    ) -> None:
         """
         Mounts the kernel file systems to the chroot environment is
         ready after the bootstrap procedure
@@ -183,9 +199,10 @@ class PackageManagerApt(PackageManagerBase):
         :param object root_bind:
             instance of RootBind to manage kernel file systems
         """
-        root_bind.mount_kernel_file_systems()
+        if root_bind:
+            root_bind.mount_kernel_file_systems()
 
-    def process_install_requests(self):
+    def process_install_requests(self) -> command_call_type:
         """
         Process package install requests for image phase (chroot)
 
@@ -213,7 +230,7 @@ class PackageManagerApt(PackageManagerBase):
             apt_get_command, self.command_env
         )
 
-    def process_delete_requests(self, force=False):
+    def process_delete_requests(self, force: bool = False) -> command_call_type:
         """
         Process package delete requests (chroot)
 
@@ -257,7 +274,7 @@ class PackageManagerApt(PackageManagerBase):
             apt_get_command, self.command_env
         )
 
-    def update(self):
+    def update(self) -> command_call_type:
         """
         Process package update requests (chroot)
 
@@ -276,7 +293,7 @@ class PackageManagerApt(PackageManagerBase):
             apt_get_command, self.command_env
         )
 
-    def process_only_required(self):
+    def process_only_required(self) -> None:
         """
         Setup package processing only for required packages
         """
@@ -284,7 +301,7 @@ class PackageManagerApt(PackageManagerBase):
             self.custom_args.append('--no-install-recommends')
         self.deboostrap_minbase = True
 
-    def process_plus_recommended(self):
+    def process_plus_recommended(self) -> None:
         """
         Setup package processing to also include recommended dependencies.
         """
@@ -292,7 +309,9 @@ class PackageManagerApt(PackageManagerBase):
             self.custom_args.remove('--no-install-recommends')
         self.deboostrap_minbase = False
 
-    def match_package_installed(self, package_name, apt_get_output):
+    def match_package_installed(
+        self, package_name: str, package_manager_output: str
+    ) -> bool:
         """
         Match expression to indicate a package has been installed
 
@@ -301,33 +320,41 @@ class PackageManagerApt(PackageManagerBase):
         be false positives due to sub package names starting with
         the same base package name
 
-        :param list package_list: list of all packages
-        :param str log_line: apt-get status line
+        :param str package_name: package_name
+        :param str package_manager_output: apt-get status line
 
-        :returns: match or None if there isn't any match
+        :returns: True|False
 
-        :rtype: match object, None
+        :rtype: bool
         """
-        return re.match(
-            '.*Unpacking ' + re.escape(package_name) + '.*', apt_get_output
+        return bool(
+            re.match(
+                '.*Unpacking {0}.*'.format(re.escape(package_name)),
+                package_manager_output
+            )
         )
 
-    def match_package_deleted(self, package_name, apt_get_output):
+    def match_package_deleted(
+        self, package_name: str, package_manager_output: str
+    ) -> bool:
         """
         Match expression to indicate a package has been deleted
 
-        :param list package_list: list of all packages
-        :param str log_line: apt-get status line
+        :param str package_name: package_name
+        :param str package_manager_output: apt-get status line
 
-        :returns: match or None if there isn't any match
+        :returns: True|False
 
-        :rtype: match object, None
+        :rtype: bool
         """
-        return re.match(
-            '.*Removing ' + re.escape(package_name) + '.*', apt_get_output
+        return bool(
+            re.match(
+                '.*Removing {0}.*'.format(re.escape(package_name)),
+                package_manager_output
+            )
         )
 
-    def _package_requests(self):
+    def _package_requests(self) -> List:
         items = self.package_requests[:]
         self.cleanup_requests()
         return items
